pub struct Marker {
pub last_read_id: String,
pub version: u32,
pub updated_at: String,
}Expand description
Represents a marker for a reading position in a timeline.
Fields
last_read_id: StringThe ID of the last read status in the timeline.
version: u32The version of the marker (incremental).
updated_at: StringWhen the marker was last updated (ISO 8601).